==> jm_basic_flutter-1.2.0.tar.gz: lib/widgets/pick_image_dialog.dart <==
import 'dart:io';
import 'package:flutter/cupertino.dart';
import 'package:image_pickers/image_pickers.dart';
import 'package:get/get.dart';
import 'package:jm_basic_flutter/jm_basic_flutter_platform_interface.dart';
import 'package:permission_handler/permission_handler.dart';

class PickImageDialog extends StatelessWidget {
  final int maxImageCount;
  final String? photoAlbumText;
  final String? cameraText;
  final String? cancelText;
  final Function(List<Media> pickData)? onFinished;
  final Function? onRequestPermissionFailed;

  const PickImageDialog({
    Key? key,
    this.maxImageCount = 9,
    this.photoAlbumText,
    this.cameraText,
    this.cancelText,
    this.onFinished,
    this.onRequestPermissionFailed,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return CupertinoActionSheet(
      actions: [
        CupertinoActionSheetAction(
          child: Text(
            photoAlbumText ?? 'c_photo_album'.tr,
            style: TextStyle(color: Color(0xFF222222)),
          ),
          onPressed: () => _onPhotoAlbumTaped(context),
        ),
        CupertinoActionSheetAction(
          child: Text(cameraText ?? 'c_camera'.tr, style: TextStyle(color: Color(0xFF222222))),
          onPressed: () => _onCameraTaped(context),
        ),
      ],
      cancelButton: CupertinoActionSheetAction(
        onPressed: () async {
          Navigator.of(context).pop();
        },
        child: Text(cancelText ?? 'cancel'.tr),
      ),
    );
  }

  void _onPhotoAlbumTaped(BuildContext context) {
    Permission.photos.request().then((status) {
      if (status.isGranted || status.isLimited) {
        if (Platform.isAndroid) {
          _onOpenAndroidAlbum(context);
        } else if (Platform.isIOS) {
          _onOpenIosAlbum(context);
        } else {
          throw UnimplementedError('${Platform.operatingSystem} are not yet supported');
        }
      } else {
        if (onRequestPermissionFailed != null) {
          onRequestPermissionFailed!();
        }
      }
    });
  }

  void _onCameraTaped(BuildContext context) {
    Permission.camera.request().then((status) {
      if (status.isGranted || status.isLimited) {
        if (Platform.isAndroid) {
          _onOpenAndroidCamera(context);
        } else if (Platform.isIOS) {
          _onOpenIosCamera(context);
        } else {
          throw UnimplementedError('${Platform.operatingSystem} are not yet supported');
        }
      } else {
        if (onRequestPermissionFailed != null) {
          onRequestPermissionFailed!();
        }
      }
    });
  }

  // 打开安卓相册
  void _onOpenAndroidAlbum(BuildContext context) {
    ImagePickers.pickerPaths(
      galleryMode: GalleryMode.image,
      selectCount: maxImageCount,
      showCamera: false,
      compressSize: 5000,
    ).then((mediaList) {
      Navigator.of(context).pop(mediaList);
      if (onFinished != null) {
        onFinished!(mediaList);
      }
    });
  }

  // 打开安卓相机
  void _onOpenAndroidCamera(BuildContext context) {
    ImagePickers.openCamera().then((image) {
      List<Media> mediaList = image != null ? [image] : [];
      Navigator.of(context).pop(mediaList);
      if (onFinished != null) {
        onFinished!(mediaList);
      }
    });
  }

  List<Media> _getIosImageMediaList(dynamic data) {
    debugPrint('makeImagePicker-data: $data');
    if (data == null) {
      return [];
    }
    List<Media> list = [];
    try {
      final imagePathList = data as List<dynamic>;
      list = imagePathList.map((e) {
        final path = (e ?? '').toString();
        return Media()
          ..thumbPath = path
          ..path = path
          ..galleryMode = GalleryMode.image;
      }).toList();
    } catch (error) {
      debugPrint(error.toString());
    }
    debugPrint('_getIosImageMediaList: $list');
    return list;
  }

  // 打开iOS相册
  void _onOpenIosAlbum(BuildContext context) {
    JmBasicFlutterPlatform.instance.makeImagePicker(maxSelectCount: maxImageCount).then((data) {
      final mediaList = _getIosImageMediaList(data);
      Navigator.of(context).pop(mediaList);
      if (onFinished != null) {
        onFinished!(mediaList);
      }
    });
  }

  // 打开iOS相机
  void _onOpenIosCamera(BuildContext context) async {
    JmBasicFlutterPlatform.instance.makeImagePicker(isCamera: true).then((data) {
      final mediaList = _getIosImageMediaList(data);
      Navigator.of(context).pop(mediaList);
      if (onFinished != null) {
        onFinished!(mediaList);
      }
    });
  }
}

==> jm_basic_flutter-1.3.1.tar.gz: lib/widgets/pick_image_dialog.dart <==
import 'dart:io';
import 'package:flutter/cupertino.dart';
import 'package:image_pickers/image_pickers.dart';
import 'package:get/get.dart';
import 'package:jm_basic_flutter/jm_basic_flutter_platform_interface.dart';
import 'package:permission_handler/permission_handler.dart';

class PickImageDialog extends StatelessWidget {
  final int maxImageCount;
  final String? photoAlbumText;
  final String? cameraText;
  final String? cancelText;
  final Function? onRequestPermissionFailed;

  const PickImageDialog({
    Key? key,
    this.maxImageCount = 9,
    this.photoAlbumText,
    this.cameraText,
    this.cancelText,
    this.onRequestPermissionFailed,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return CupertinoActionSheet(
      actions: [
        CupertinoActionSheetAction(
          child: Text(
            photoAlbumText ?? 'c_photo_album'.tr,
            style: TextStyle(color: Color(0xFF222222)),
          ),
          onPressed: () => _onPhotoAlbumTaped(),
        ),
        CupertinoActionSheetAction(
          child: Text(cameraText ?? 'c_camera'.tr, style: TextStyle(color: Color(0xFF222222))),
          onPressed: () => _onCameraTaped(),
        ),
      ],
      cancelButton: CupertinoActionSheetAction(
        onPressed: () => Get.back(),
        child: Text(cancelText ?? 'cancel'.tr),
      ),
    );
  }

  void _onPhotoAlbumTaped() {
    Permission.photos.request().then((status) {
      if (status.isGranted || status.isLimited) {
        if (Platform.isAndroid) {
          _onOpenAndroidAlbum();
        } else if (Platform.isIOS) {
          _onOpenIosAlbum();
        } else {
          throw UnimplementedError('${Platform.operatingSystem} are not yet supported');
        }
      } else {
        if (onRequestPermissionFailed != null) {
          onRequestPermissionFailed!();
        }
      }
    });
  }

  void _onCameraTaped() {
    Permission.camera.request().then((status) {
      if (status.isGranted || status.isLimited) {
        if (Platform.isAndroid) {
          _onOpenAndroidCamera();
        } else if (Platform.isIOS) {
          _onOpenIosCamera();
        } else {
          throw UnimplementedError('${Platform.operatingSystem} are not yet supported');
        }
      } else {
        if (onRequestPermissionFailed != null) {
          onRequestPermissionFailed!();
        }
      }
    });
  }

  // 打开安卓相册
  void _onOpenAndroidAlbum() {
    ImagePickers.pickerPaths(
      galleryMode: GalleryMode.image,
      selectCount: maxImageCount,
      showCamera: false,
      compressSize: 5000,
    ).then((mediaList) {
      Get.back(result: mediaList);
    });
  }

  // 打开安卓相机
  void _onOpenAndroidCamera() {
    ImagePickers.openCamera().then((image) {
      List<Media> mediaList = image != null ? [image] : [];
      Get.back(result: mediaList);
    });
  }

  List<Media> _getIosImageMediaList(dynamic data) {
    debugPrint('makeImagePicker-data: $data');
    if (data == null) {
      return [];
    }
    List<Media> list = [];
    try {
      final imagePathList = data as List<dynamic>;
      list = imagePathList.map((e) {
        final path = (e ?? '').toString();
        return Media()
          ..thumbPath = path
          ..path = path
          ..galleryMode = GalleryMode.image;
      }).toList();
    } catch (error) {
      debugPrint(error.toString());
    }
    debugPrint('_getIosImageMediaList: $list');
    return list;
  }

  // 打开iOS相册
  void _onOpenIosAlbum() {
    JmBasicFlutterPlatform.instance.makeImagePicker(maxSelectCount: maxImageCount).then((data) {
      final mediaList = _getIosImageMediaList(data);
      Get.back(result: mediaList);
    });
  }

  // 打开iOS相机
  void _onOpenIosCamera() async {
    JmBasicFlutterPlatform.instance.makeImagePicker(isCamera: true).then((data) {
      final mediaList = _getIosImageMediaList(data);
      Get.back(result: mediaList);
    });
  }
}
